@@ -260,6 +260,10 @@ class APIConnection:
                     result = pd.merge(result, tdf, on=ids)
                 except UnboundLocalError:
                     result = tdf
+                except KeyError:
+                    print(tdf.columns)
+                    print(result.columns)
+                    print(ids)
             return result
 
     def varslike(self, pattern=None, by=None, engine="re", within=None):
